@@ -7,7 +7,7 @@ use tracing::info;
 
 #[derive(Clone, Serialize, Deserialize)]
 pub struct QueueItem {
-    pub number: Vec<u64>,
+    pub numbers: Vec<u64>,
     pub program: Vec<String>
 }
 
